==> keycloak-model-map-18.0.2-sources.jar: org/keycloak/models/map/userSession/MapUserSessionEntityDelegate.java <==
package org.keycloak.models.map.userSession;
public class MapUserSessionEntityDelegate implements org.keycloak.models.map.userSession.MapUserSessionEntity {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.userSession.MapUserSessionEntity> delegateProvider;
    public MapUserSessionEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.userSession.MapUserSessionEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.ID).getId();
    }
    @Override public void setId(String id) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.userSession.MapUserSessionEntityFields.ID, id).setId(id);
    }
    @Override public String getRealmId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.REALM_ID).getRealmId();
    }
    @Override public void setRealmId(String realmId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.userSession.MapUserSessionEntityFields.REALM_ID, realmId).setRealmId(realmId);
    }
    @Override public String getUserId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.USER_ID).getUserId();
    }
    @Override public void setUserId(String userId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.userSession.MapUserSessionEntityFields.USER_ID, userId).setUserId(userId);
    }
    @Override public String getBrokerSessionId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.BROKER_SESSION_ID).getBrokerSessionId();
    }
    @Override public void setBrokerSessionId(String brokerSessionId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.userSession.MapUserSessionEntityFields.BROKER_SESSION_ID, brokerSessionId).setBrokerSessionId(brokerSessionId);
    }
    @Override public String getBrokerUserId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.BROKER_USER_ID).getBrokerUserId();
    }
    @Override public void setBrokerUserId(String brokerUserId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.userSession.MapUserSessionEntityFields.BROKER_USER_ID, brokerUserId).setBrokerUserId(brokerUserId);
    }
    @Override public String getLoginUsername() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.LOGIN_USERNAME).getLoginUsername();
    }
    @Override public void setLoginUsername(String loginUsername) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.userSession.MapUserSessionEntityFields.LOGIN_USERNAME, loginUsername).setLoginUsername(loginUsername);
    }
    @Override public String getIpAddress() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.IP_ADDRESS).getIpAddress();
    }
    @Override public void setIpAddress(String ipAddress) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.userSession.MapUserSessionEntityFields.IP_ADDRESS, ipAddress).setIpAddress(ipAddress);
    }
    @Override public String getAuthMethod() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.AUTH_METHOD).getAuthMethod();
    }
    @Override public void setAuthMethod(String authMethod) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.userSession.MapUserSessionEntityFields.AUTH_METHOD, authMethod).setAuthMethod(authMethod);
    }
    @Override public Boolean isRememberMe() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.REMEMBER_ME).isRememberMe();
    }
    @Override public void setRememberMe(Boolean rememberMe) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.userSession.MapUserSessionEntityFields.REMEMBER_ME, rememberMe).setRememberMe(rememberMe);
    }
    @Override public Long getStarted() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.STARTED).getStarted();
    }
    @Override public void setStarted(Long started) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.userSession.MapUserSessionEntityFields.STARTED, started).setStarted(started);
    }
    @Override public Long getLastSessionRefresh() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.LAST_SESSION_REFRESH).getLastSessionRefresh();
    }
    @Override public void setLastSessionRefresh(Long lastSessionRefresh) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.userSession.MapUserSessionEntityFields.LAST_SESSION_REFRESH, lastSessionRefresh).setLastSessionRefresh(lastSessionRefresh);
    }
    @Override public Long getExpiration() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.EXPIRATION).getExpiration();
    }
    @Override public void setExpiration(Long expiration) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.userSession.MapUserSessionEntityFields.EXPIRATION, expiration).setExpiration(expiration);
    }
    @Override public java.util.Map<String,String> getNotes() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.NOTES).getNotes();
    }
    @Override public String getNote(String name) {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.NOTES, name).getNote(name);
    }
    @Override public void setNotes(java.util.Map<String,String> notes) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.userSession.MapUserSessionEntityFields.NOTES, notes).setNotes(notes);
    }
    @Override public Boolean removeNote(String name) {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.NOTES, name).removeNote(name);
    }
    @Override public void setNote(String name, String value) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.userSession.MapUserSessionEntityFields.NOTES, name, value).setNote(name, value);
    }
    @Override public org.keycloak.models.UserSessionModel.State getState() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.STATE).getState();
    }
    @Override public void setState(org.keycloak.models.UserSessionModel.State state) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.userSession.MapUserSessionEntityFields.STATE, state).setState(state);
    }
    @Override public java.util.Map<String,String> getAuthenticatedClientSessions() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.AUTHENTICATED_CLIENT_SESSIONS).getAuthenticatedClientSessions();
    }
    @Override public void setAuthenticatedClientSessions(java.util.Map<String,String> authenticatedClientSessions) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.userSession.MapUserSessionEntityFields.AUTHENTICATED_CLIENT_SESSIONS, authenticatedClientSessions).setAuthenticatedClientSessions(authenticatedClientSessions);
    }
    @Override public String getAuthenticatedClientSession(String clientUUID) {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.AUTHENTICATED_CLIENT_SESSIONS, clientUUID).getAuthenticatedClientSession(clientUUID);
    }
    @Override public void setAuthenticatedClientSession(String clientUUID, String clientSessionId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.userSession.MapUserSessionEntityFields.AUTHENTICATED_CLIENT_SESSIONS, clientUUID, clientSessionId).setAuthenticatedClientSession(clientUUID, clientSessionId);
    }
    @Override public Boolean removeAuthenticatedClientSession(String clientUUID) {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.AUTHENTICATED_CLIENT_SESSIONS, clientUUID).removeAuthenticatedClientSession(clientUUID);
    }
    @Override public Boolean isOffline() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.OFFLINE).isOffline();
    }
    @Override public void setOffline(Boolean offline) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.userSession.MapUserSessionEntityFields.OFFLINE, offline).setOffline(offline);
    }
    @Override public org.keycloak.models.UserSessionModel.SessionPersistenceState getPersistenceState() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.PERSISTENCE_STATE).getPersistenceState();
    }
    @Override public void setPersistenceState(org.keycloak.models.UserSessionModel.SessionPersistenceState persistenceState) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.userSession.MapUserSessionEntityFields.PERSISTENCE_STATE, persistenceState).setPersistenceState(persistenceState);
    }
}

==> keycloak-model-map-20.0.3-sources.jar: org/keycloak/models/map/userSession/MapUserSessionEntityDelegate.java <==
package org.keycloak.models.map.userSession;
public class MapUserSessionEntityDelegate implements org.keycloak.models.map.userSession.MapUserSessionEntity {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.userSession.MapUserSessionEntity> delegateProvider;
    public MapUserSessionEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.userSession.MapUserSessionEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.ID).getId();
    }
    @Override public void setId(String id) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.userSession.MapUserSessionEntityFields.ID, id).setId(id);
    }
    @Override public Long getExpiration() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.EXPIRATION).getExpiration();
    }
    @Override public void setExpiration(Long expiration) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.userSession.MapUserSessionEntityFields.EXPIRATION, expiration).setExpiration(expiration);
    }
    @Override public String getRealmId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.REALM_ID).getRealmId();
    }
    @Override public void setRealmId(String realmId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.userSession.MapUserSessionEntityFields.REALM_ID, realmId).setRealmId(realmId);
    }
    @Override public String getUserId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.USER_ID).getUserId();
    }
    @Override public void setUserId(String userId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.userSession.MapUserSessionEntityFields.USER_ID, userId).setUserId(userId);
    }
    @Override public String getBrokerSessionId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.BROKER_SESSION_ID).getBrokerSessionId();
    }
    @Override public void setBrokerSessionId(String brokerSessionId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.userSession.MapUserSessionEntityFields.BROKER_SESSION_ID, brokerSessionId).setBrokerSessionId(brokerSessionId);
    }
    @Override public String getBrokerUserId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.BROKER_USER_ID).getBrokerUserId();
    }
    @Override public void setBrokerUserId(String brokerUserId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.userSession.MapUserSessionEntityFields.BROKER_USER_ID, brokerUserId).setBrokerUserId(brokerUserId);
    }
    @Override public String getLoginUsername() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.LOGIN_USERNAME).getLoginUsername();
    }
    @Override public void setLoginUsername(String loginUsername) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.userSession.MapUserSessionEntityFields.LOGIN_USERNAME, loginUsername).setLoginUsername(loginUsername);
    }
    @Override public String getIpAddress() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.IP_ADDRESS).getIpAddress();
    }
    @Override public void setIpAddress(String ipAddress) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.userSession.MapUserSessionEntityFields.IP_ADDRESS, ipAddress).setIpAddress(ipAddress);
    }
    @Override public String getAuthMethod() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.AUTH_METHOD).getAuthMethod();
    }
    @Override public void setAuthMethod(String authMethod) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.userSession.MapUserSessionEntityFields.AUTH_METHOD, authMethod).setAuthMethod(authMethod);
    }
    @Override public Boolean isRememberMe() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.REMEMBER_ME).isRememberMe();
    }
    @Override public void setRememberMe(Boolean rememberMe) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.userSession.MapUserSessionEntityFields.REMEMBER_ME, rememberMe).setRememberMe(rememberMe);
    }
    @Override public Long getTimestamp() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.TIMESTAMP).getTimestamp();
    }
    @Override public void setTimestamp(Long timestamp) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.userSession.MapUserSessionEntityFields.TIMESTAMP, timestamp).setTimestamp(timestamp);
    }
    @Override public Long getLastSessionRefresh() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.LAST_SESSION_REFRESH).getLastSessionRefresh();
    }
    @Override public void setLastSessionRefresh(Long lastSessionRefresh) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.userSession.MapUserSessionEntityFields.LAST_SESSION_REFRESH, lastSessionRefresh).setLastSessionRefresh(lastSessionRefresh);
    }
    @Override public java.util.Map<String,String> getNotes() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.NOTES).getNotes();
    }
    @Override public String getNote(String name) {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.NOTES, name).getNote(name);
    }
    @Override public void setNotes(java.util.Map<String,String> notes) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.userSession.MapUserSessionEntityFields.NOTES, notes).setNotes(notes);
    }
    @Override public Boolean removeNote(String name) {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.NOTES, name).removeNote(name);
    }
    @Override public void setNote(String name, String value) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.userSession.MapUserSessionEntityFields.NOTES, name, value).setNote(name, value);
    }
    @Override public org.keycloak.models.UserSessionModel.State getState() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.STATE).getState();
    }
    @Override public void setState(org.keycloak.models.UserSessionModel.State state) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.userSession.MapUserSessionEntityFields.STATE, state).setState(state);
    }
    @Override public java.util.Set<org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntity> getAuthenticatedClientSessions() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.AUTHENTICATED_CLIENT_SESSIONS).getAuthenticatedClientSessions();
    }
    @Override public java.util.Optional<org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntity> getAuthenticatedClientSession(String clientUUID) {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.AUTHENTICATED_CLIENT_SESSIONS, clientUUID).getAuthenticatedClientSession(clientUUID);
    }
    @Override public void addAuthenticatedClientSession(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntity clientSession) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.userSession.MapUserSessionEntityFields.AUTHENTICATED_CLIENT_SESSIONS, clientSession).addAuthenticatedClientSession(clientSession);
    }
    @Override public Boolean removeAuthenticatedClientSession(String clientUUID) {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.AUTHENTICATED_CLIENT_SESSIONS, clientUUID).removeAuthenticatedClientSession(clientUUID);
    }
    @Override public void clearAuthenticatedClientSessions() {
        delegateProvider.getDelegate(false, null).clearAuthenticatedClientSessions();
    }
    @Override public Boolean isOffline() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.OFFLINE).isOffline();
    }
    @Override public void setOffline(Boolean offline) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.userSession.MapUserSessionEntityFields.OFFLINE, offline).setOffline(offline);
    }
    @Override public org.keycloak.models.UserSessionModel.SessionPersistenceState getPersistenceState() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.userSession.MapUserSessionEntityFields.PERSISTENCE_STATE).getPersistenceState();
    }
    @Override public void setPersistenceState(org.keycloak.models.UserSessionModel.SessionPersistenceState persistenceState) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.userSession.MapUserSessionEntityFields.PERSISTENCE_STATE, persistenceState).setPersistenceState(persistenceState);
    }
}
